@@ -3,7 +3,6 @@ from openstates.scrape import Event as ScrapeEvent
 from openstates.importers import (
     EventImporter,
     OrganizationImporter,
-    PersonImporter,
     BillImporter,
     VoteEventImporter,
 )
@@ -42,7 +41,6 @@ def ge():
 
 
 oi = OrganizationImporter("jid")
-pi = PersonImporter("jid")
 bi = BillImporter("jid")
 vei = VoteEventImporter("jid", bi)
 
@@ -52,7 +50,9 @@ def test_related_people_event():
     create_jurisdiction()
     george = Person.objects.create(id="gw", name="George Washington")
     john = Person.objects.create(id="jqp", name="John Q. Public")
-    o = Organization.objects.create(name="Merica", jurisdiction_id="jid")
+    o = Organization.objects.create(
+        name="Merica", jurisdiction_id="jid", classification="legislature"
+    )
 
     Membership.objects.create(person=george, organization=o)
     Membership.objects.create(person=john, organization=o)
@@ -65,10 +65,10 @@ def test_related_people_event():
         item.add_person(person="John Q. Public")
         event.add_person("George Washington")
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event1.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event1.as_dict()])
     assert result["event"]["insert"] == 1
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event2.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event2.as_dict()])
     assert result["event"]["noop"] == 1
 
     assert (
@@ -108,10 +108,10 @@ def test_related_vote_event():
         item = event.add_agenda_item("Cookies will be served")
         item.add_vote_event(vote_event="Roll no. 12")
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event1.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event1.as_dict()])
     assert result["event"]["insert"] == 1
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event2.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event2.as_dict()])
     assert result["event"]["noop"] == 1
 
     assert (
@@ -136,10 +136,10 @@ def test_related_bill_event():
         item = event.add_agenda_item("Cookies will be served")
         item.add_bill(bill="HB 101")
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event1.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event1.as_dict()])
     assert result["event"]["insert"] == 1
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event2.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event2.as_dict()])
     assert result["event"]["noop"] == 1
 
     assert (
@@ -173,10 +173,10 @@ def test_related_committee_event():
         item = event.add_agenda_item("Cookies will be served")
         item.add_committee(committee="Fiscal Committee")
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event1.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event1.as_dict()])
     assert result["event"]["insert"] == 1
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event2.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event2.as_dict()])
     assert result["event"]["noop"] == 1
 
     assert (
@@ -202,10 +202,10 @@ def test_media_event():
             url="http://hello.world/foo",
         )
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event1.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event1.as_dict()])
     assert result["event"]["insert"] == 1
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event2.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event2.as_dict()])
     assert result["event"]["noop"] == 1
 
 
@@ -220,10 +220,10 @@ def test_media_document():
             note="Presentation", url="http://example.com/presentation.pdf"
         )
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event1.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event1.as_dict()])
     assert result["event"]["insert"] == 1
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event2.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event2.as_dict()])
     assert result["event"]["noop"] == 1
 
 
@@ -236,22 +236,22 @@ def test_full_event():
 
     event = ge()
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event.as_dict()])
     assert result["event"]["insert"] == 1
 
     event = ge()
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event.as_dict()])
     assert result["event"]["noop"] == 1
 
     event = ge()
     event.location["name"] = "United States of America"
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event.as_dict()])
     assert result["event"]["update"] == 1
 
 
 @pytest.mark.django_db
-def test_pupa_identifier_event():
+def test_dedupe_key_event():
     create_jurisdiction()
     create_other_jurisdiction()
     george = Person.objects.create(id="gw", name="George Washington")
@@ -259,24 +259,24 @@ def test_pupa_identifier_event():
     Membership.objects.create(person=george, organization=o)
 
     event = ge()
-    event.pupa_id = "foo"
+    event.dedupe_key = "foo"
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event.as_dict()])
     assert result["event"]["insert"] == 1
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event.as_dict()])
     assert result["event"]["noop"] == 1
 
     event.name = ("America's Anniversary",)
     event.location["name"] = "United States of America"
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event.as_dict()])
     assert result["event"]["update"] == 1
 
-    event.pupa_id = "bar"
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event.as_dict()])
+    event.dedupe_key = "bar"
+    result = EventImporter("jid", oi, bi, vei).import_data([event.as_dict()])
     assert result["event"]["insert"] == 1
 
-    result = EventImporter("ojid", oi, pi, bi, vei).import_data([event.as_dict()])
+    result = EventImporter("ojid", oi, bi, vei).import_data([event.as_dict()])
     assert result["event"]["insert"] == 1
 
 
@@ -287,7 +287,7 @@ def test_pupa_identifier_event():
 #     event.start_date = '2017'
 #     pytest.raises(
 #         ValueError,
-#         EventImporter('jid', oi, pi, bi, vei).import_item,
+#         EventImporter('jid', oi, bi, vei).import_item,
 #         event.as_dict()
 #     )
 
@@ -308,10 +308,10 @@ def test_top_level_media_event():
         media_type="application/octet-stream",
     )
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event1.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event1.as_dict()])
     assert result["event"]["insert"] == 1
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event2.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event2.as_dict()])
     assert result["event"]["noop"] == 1
 
 
@@ -323,7 +323,7 @@ def test_event_agenda_item():
     agenda = event1.add_agenda_item("first item")
     agenda["extras"] = {"one": 1, "two": [2]}
 
-    result = EventImporter("jid", oi, pi, bi, vei).import_data([event1.as_dict()])
+    result = EventImporter("jid", oi, bi, vei).import_data([event1.as_dict()])
     assert result["event"]["insert"] == 1
 
     e = Event.objects.get()
